@@ -7,22 +7,16 @@ pub struct State {
   pub unicode_supported: bool,
   pub history: Vec<String>,
   pub commands: Vec<crate::Command>,
-  pub last_exit_code: i32,
 }
 
 impl State {
   pub(crate) fn new(commands: &[crate::Command], unicode_supported: bool) -> Self {
     Self {
-      environment: {
-        let mut environment = BTreeMap::new();
-        environment.insert("last-exit-code".into(), "0".into());
-        environment
-      },
+      environment: BTreeMap::new(),
       unicode_supported,
       prompt: if unicode_supported { "❯ " } else { "> " }.into(),
       commands: commands.to_vec(),
       history: Vec::new(),
-      last_exit_code: 0,
     }
   }
 
@@ -34,9 +28,4 @@ impl State {
     #[cfg(feature = "std")]
     std::env::set_var(key.as_ref(), value.as_ref());
   }
-
-  pub fn set_last_exit_code(&mut self, code: i32) {
-    self.last_exit_code = code;
-    self.set_environment_variable("last-exit-code", "0");
-  }
 }
